summaryrefslogtreecommitdiffstats
path: root/test/tmisc.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2018-11-04 06:27:23 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2018-11-04 06:27:23 (GMT)
commit1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96 (patch)
treec1f53073ff700c02397231fec2b2075a7391d87f /test/tmisc.c
parentdeb75622ca18958ea729c7184c4bc5ea0e029280 (diff)
downloadhdf5-1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96.zip
hdf5-1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96.tar.gz
hdf5-1daa7b830ac9ce6028c21f22fddaa67bd4dc8d96.tar.bz2
Switch driver | plugin => connector.
Diffstat (limited to 'test/tmisc.c')
-rw-r--r--test/tmisc.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/test/tmisc.c b/test/tmisc.c
index 02521e4..fef94dd 100644
--- a/test/tmisc.c
+++ b/test/tmisc.c
@@ -3481,15 +3481,15 @@ test_misc19(void)
HDfree(vfd_cls);
-/* Check H5I operations on virtual object plugins */
+/* Check H5I operations on virtual object connectors */
/* Get a VOL class to register */
vol_cls = h5_get_dummy_vol_class();
CHECK(vol_cls, NULL, "h5_get_dummy_vol_class");
- /* Register a VOL plugin */
- volid = H5VLregister_plugin(vol_cls, H5P_DEFAULT);
- CHECK(volid, FAIL, "H5VLregister_plugin");
+ /* Register a VOL connector */
+ volid = H5VLregister_connector(vol_cls, H5P_DEFAULT);
+ CHECK(volid, FAIL, "H5VLregister_connector");
/* Check the reference count */
rc = H5Iget_ref(volid);
@@ -3499,23 +3499,23 @@ test_misc19(void)
rc = H5Iinc_ref(volid);
VERIFY(rc, 2, "H5Iinc_ref");
- /* Unregister the VOL plugin normally */
- ret = H5VLunregister_plugin(volid);
- CHECK(ret, FAIL, "H5VLunregister_plugin");
+ /* Unregister the VOL connector normally */
+ ret = H5VLunregister_connector(volid);
+ CHECK(ret, FAIL, "H5VLunregister_connector");
/* Check the reference count */
rc = H5Iget_ref(volid);
VERIFY(rc, 1, "H5Iget_ref");
/* Unregister the VOL plugin by decrementing the reference count */
rc = H5Idec_ref(volid);
VERIFY(rc, 0, "H5Idec_ref");
/* Try unregistering the VOL plugin again (should fail) */
H5E_BEGIN_TRY {
- ret = H5VLunregister_plugin(volid);
+ ret = H5VLunregister_connector(volid);
} H5E_END_TRY;
- VERIFY(ret, FAIL, "H5VLunregister_plugin");
+ VERIFY(ret, FAIL, "H5VLunregister_connector");
HDfree(vol_cls);
@@ -3499,23 +3499,23 @@ test_misc19(void)
rc = H5Iget_ref(volid);
VERIFY(rc, 1, "H5Iget_ref");
- /* Unregister the VOL plugin by decrementing the reference count */
+ /* Unregister the VOL connector by decrementing the reference count */
rc = H5Idec_ref(volid);
VERIFY(rc, 0, "H5Idec_ref");
@@ -3499,23 +3499,23 @@ test_misc19(void)
rc = H5Idec_ref(volid);
VERIFY(rc, 0, "H5Idec_ref");
- /* Try unregistering the VOL plugin again (should fail) */
+ /* Try unregistering the VOL connector again (should fail) */
H5E_BEGIN_TRY {